@@ -4,7 +4,7 @@ use Digest::SHA1 qw(sha1_hex);
 use File::Slurp::Tiny qw(read_file);
 use Moo;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 # todo, type checking?
 
@@ -72,15 +72,25 @@ sub _sig {
 
 1;
 
+# ABSTRACT: Caching model for Code::TidyAll
+
+__END__
+
+=pod
+
 =head1 NAME
 
-Code::TidyAll::CacheModel - caching model for Cody::TidyAll
+Code::TidyAll::CacheModel - Caching model for Code::TidyAll
+
+=head1 VERSION
+
+version 0.27
 
 =head1 SYNOPSIS
 
   my $cache_model = Cody::TidyAll::CacheModel->new(
-     cache_engine => Code::TidyAll::Cache->new(...),
-     path => "/path/to/file/to/cache",
+      cache_engine => Code::TidyAll::Cache->new(...),
+      path         => "/path/to/file/to/cache",
   );
 
   # check cache
@@ -91,7 +101,7 @@ Code::TidyAll::CacheModel - caching model for Cody::TidyAll
   $cache_model->update;
 
   # update the cache when you know the file contents
-  $cache_model->file_contents( $new_content );
+  $cache_model->file_contents($new_content);
   $cache_model->update;
 
   # force removal from cache
@@ -158,4 +168,29 @@ Attempts to remove the value from the cache
 
 =back
 
+=head1 SEE ALSO
 
+L<Code::TidyAll>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=cut
