@@ -3,7 +3,7 @@ package Code::TidyAll::CacheModel::Shared;
 use Moo;
 extends 'Code::TidyAll::CacheModel';
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 sub _build_cache_key {
     my $self = shift;
@@ -25,17 +25,25 @@ sub remove {
 
 1;
 
+# ABSTRACT: Shared cache model for Code::TidyAll
+
 __END__
 
+=pod
+
 =head1 NAME
 
-Code::TidyAll:CacheModel::Shared - shared cache model for Code::TidyAll
+Code::TidyAll::CacheModel::Shared - Shared cache model for Code::TidyAll
+
+=head1 VERSION
+
+version 0.27
 
 =head1 SYNOPSIS
 
    my $cta = Code::TidyAll->new(
-     cache_model_class => 'Code::TidyAll::CacheModel::Shared',
-     ...
+       cache_model_class => 'Code::TidyAll::CacheModel::Shared',
+       ...
    );
 
 =head1 DESCRIPTION
@@ -51,3 +59,29 @@ This allows you to share a cache when you might have several versions of a file
 that you switch backwards and forwards between (e.g. when you're working on
 several branches) and keep the cache values
 
+=head1 SEE ALSO
+
+L<Code::TidyAll>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=cut
