@@ -11,7 +11,7 @@ use IPC::System::Simple qw(capturex run);
 use Moo;
 use Try::Tiny;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 # Public
 has 'conf_name'       => ( is => 'ro' );
@@ -80,9 +80,14 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Code::TidyAll::Git::Precommit - Git pre-commit hook that requires files to be
+tidyall'd
+
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
