@@ -9,7 +9,7 @@ use IPC::System::Simple qw(capturex run);
 use Moo;
 use Try::Tiny;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 # Public
 has 'allow_repeated_push' => ( is => 'ro', default => 3 );
@@ -146,15 +146,20 @@ sub check_repeated_push {
 
 1;
 
-# ABSTRACT: Git pre-receive hook that requires files to betidyall'd
+# ABSTRACT: Git pre-receive hook that requires files to be tidyall'd
 
 __END__
 
 =pod
 
+=head1 NAME
+
+Code::TidyAll::Git::Prereceive - Git pre-receive hook that requires files to be
+tidyall'd
+
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
