@@ -6,7 +6,7 @@ use warnings;
 use JSON ();
 use Moo;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 extends 'Code::TidyAll::Plugin';
 
@@ -31,9 +31,14 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Code::TidyAll::Plugin::JSON - Use the JSON module to tidy JSON documents with
+tidyall
+
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
