@@ -5,7 +5,7 @@ use Perl::Tidy;
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 sub transform_source {
     my ( $self, $source ) = @_;
@@ -35,13 +35,19 @@ sub transform_source {
 
 1;
 
+# ABSTRACT: Use perltidy with tidyall
+
 __END__
 
 =pod
 
 =head1 NAME
 
-Code::TidyAll::Plugin::PerlTidy - use perltidy with tidyall
+Code::TidyAll::Plugin::PerlTidy - Use perltidy with tidyall
+
+=head1 VERSION
+
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -79,3 +85,29 @@ Arguments to pass to perltidy
 
 =back
 
+=head1 SEE ALSO
+
+L<Code::TidyAll>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
+
+=cut
