@@ -9,7 +9,7 @@ use Moo;
 use Text::ParseWords qw(shellwords);
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 has 'ispell_argv' => ( is => 'ro', default => q{} );
 has 'ispell_cmd'  => ( is => 'ro', default => 'ispell' );
@@ -52,9 +52,13 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Code::TidyAll::Plugin::PodSpell - Use Pod::Spell + ispell with tidyall
+
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
