@@ -8,7 +8,7 @@ use Moo;
 use SVN::Look;
 use Try::Tiny;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 # Public
 has 'conf_name'                => ( is => 'ro' );
@@ -168,9 +168,14 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Code::TidyAll::SVN::Precommit - Subversion pre-commit hook that requires files
+to be tidyall'd
+
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
