@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 my $test = Test::Builder->new;
 
@@ -66,9 +66,14 @@ __END__
 
 =pod
 
+=head1 NAME
+
+Test::Code::TidyAll - Check that all your files are tidy and valid according to
+tidyall
+
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
